import { http } from '@/utils/http';

/*通过id查询公文数据*/
export function queryDocumentByIdApi(id : string) {
	return http({
		url: '/cxcoagwfb/cxcOaGwfb/queryById',
		method: 'GET',
		data: { id }
	})
}


/*通过id查询干租车数据*/
export function queryCarRentalByIdApi(id : string) {
	return http({
		url: '/CarRental/cxcCarRental/queryById',
		method: 'GET',
		data: { id }
	})
}

/*通过id查询指标考核主表数据*/
export function queryZbkhZbByIdApi(id : string) {
	return http({
		url: '/jxkh.zbkh/cxcJxkhZbkhZb/listById',
		method: 'GET',
		data: { id }
	})
}

/*通过id查询指标考核子表数据*/
export function queryZbkhFbByIdApi(data : object) {
	return http({
		url: '/jxkh.zbkh/cxcJxkhZbkhZb/listCxcJxkhZbkhDwkhByMainId',
		method: 'GET',
		data
	})
}

/*通过id查询指标考核自定义表头*/
export function queryZbkhBtByIdApi(mainId : string) {
	return http({
		url: '/jxkh.dwkhbt/cxcJxkhZbkhDwkhBtZb/listByMainId',
		method: 'GET',
		data: { mainId }
	})
}

/*通过id查询考核实施主表数据*/
export function queryKhssZbByIdApi(id : string) {
	return http({
		url: '/jxkh.khss/cxcJxkhXhss/getAllById',
		method: 'GET',
		data: { id }
	})
}

 /*通过id查询考核实施主表自定义表头*/
 export function queryKhssZbBtByIdApi(mainId : string) {
 	return http({
 		url: '/jxkh.jxkh/cxcJxkhKhssKhjxZb/getByMainId',
 		method: 'GET',
 		data: { mainId }
 	})
 }
 
 /*通过id查询考核实施子表数据*/
 export function queryKhssFbByIdApi(data : object) {
 	return http({
 		url: '/jxkh.khss/cxcJxkhXhss/selectAllByMainId',
 		method: 'GET',
 		data
 	})
 }
 
 /*通过id查询总金额*/
 export function queryKhssAllSumByIdApi(mainId : string) {
 	return http({
 		url: '/jxkh.khss/cxcJxkhXhss/getAllSum',
 		method: 'GET',
 		data: { mainId }
 	})
 }
 
 /*通过id查询考核实子表自定义表头*/
 export function queryKhssFbBtByIdApi(mainId : string) {
 	return http({
 		url: '/jxkh.jxfp.bt/cxcJxkhJxfbBtZb/listByMainId',
 		method: 'GET',
 		data: { mainId }
 	})
 }
